@@ -948,6 +948,54 @@ public class BlankPanel extends JPanel
 		}
 	}
 
+    /**
+	 * Add a label and a textfield to a panel, assumed to be using
+	 * GridBagLayout.
+	 */
+	protected void addEntryField( JPanel panel, JComponent label,
+	                              JComponent field, JComponent unit ) {
+		Component endGlue = STRETCH_FIELDS ? null : Box.createGlue();
+		Component lastItem =
+		              STRETCH_FIELDS ? ((unit != null) ? unit : field) : endGlue;
+		GridBagConstraints gbc = getGBC();
+		gbc.fill = gbc.NONE;
+		gbc.weightx = 0.0;
+		gbc.gridwidth = 1;
+		gbc.gridx = 0;
+		gbc.anchor = gbc.EAST;
+		int space = UIFactory.getComponentSpace();
+		gbc.insets = new Insets( space, space, 0, space/2 );
+		panel.add( label, gbc );
+
+		gbc.gridx++;
+		gbc.anchor = gbc.WEST;
+		gbc.insets = new Insets( space, 0, 0, 0 );
+		if ( STRETCH_FIELDS ) {
+			gbc.fill = gbc.HORIZONTAL;
+			gbc.weightx = 1.0;
+		}
+		gbc.gridwidth = (lastItem == field) ? gbc.REMAINDER : 1;
+		panel.add( field, gbc );
+
+		if ( unit != null ) {
+			gbc.gridx++;
+			gbc.fill = gbc.NONE;
+			gbc.weightx = 0.0;
+			gbc.insets = new Insets( space, space/2, 0, 0 );
+			gbc.gridwidth = (lastItem == unit) ? gbc.REMAINDER : 1;
+			panel.add( unit, gbc );
+		}
+
+		if ( !STRETCH_FIELDS ) {
+			gbc.gridx++;
+			gbc.anchor = gbc.EAST;
+			gbc.fill = gbc.HORIZONTAL;
+			gbc.weightx = 1.0;
+			gbc.gridwidth = gbc.REMAINDER;
+			panel.add( endGlue, gbc );
+		}
+	}
+
     /**
 	 * Add a label and a textfield to a panel, assumed to be using
 	 * GridBagLayout.
