@@ -619,6 +619,57 @@ public class EncryptionPanel extends BlankPanel
 		_cbConsoleSSL.setEnabled(_configData.sslServerOn && !_rbRequired.isSelected());
 		_cbSSLCheckHostName.setEnabled(_configData.sslServerOn);
 
+		// Get secure port
+		DSResourceModel model = (DSResourceModel)getModel();
+		ConsoleInfo serverInfo = model.getServerInfo();
+		LDAPConnection ldc = serverInfo.getLDAPConnection();
+		int securePort = -1; 
+		// Read cn=config
+		String configDn = "cn=config";
+		String[] configAttrs = { "nsslapd-secureport" };
+		LDAPEntry configEntry = null;
+		try {
+		    configEntry = ldc.read(configDn, configAttrs);
+		}
+		catch(LDAPException x) {
+		    Debug.println(0, 
+		        "EncryptionPanel.updateComponentState: failure while reading config data");
+		    if (Debug.getTrace()) {
+		        x.printStackTrace();
+		    }
+		}
+
+		// Parse configEntry
+		if (configEntry != null) {
+		    String securePortStr = DSUtil.getAttrValue(configEntry, configAttrs[0]);
+		    try {
+		        securePort = Integer.parseInt(securePortStr);
+		    }
+		    catch(NumberFormatException x) {
+		        Debug.println(0, 
+		            "EncryptionPanel.updateComponentState: cannot convert nsslapd-secureport to an int !");
+		    }
+
+		    // If securePort is not a default value, set it to NetscapeRoot
+		    if (636 != securePort) {
+		        ConsoleInfo consoleInfo = model.getConsoleInfo();
+		        LDAPConnection sieldc = consoleInfo.getLDAPConnection();
+		        String sieDn = consoleInfo.getCurrentDN();
+		        LDAPAttribute attr = 
+		                 new LDAPAttribute("nssecureserverport", securePortStr);
+		        try {
+		            sieldc.modify(sieDn, 
+		                 new LDAPModification(LDAPModification.REPLACE, attr));
+		        }
+		        catch(LDAPException xx) {
+		            Debug.println(0, 
+		                "EncryptionPanel.updateComponentState: failure while modifying console config data");
+		            if (Debug.getTrace()) {
+		                xx.printStackTrace();
+		            }
+		        }
+		    }
+		}
 	}
 	
 	
