@@ -83,10 +83,7 @@ public class NewLDBMPanel extends BlankPanel {
         gbc.fill = gbc.HORIZONTAL;
         grid.add( panel, gbc );
 
-        LDAPAttribute suffixCN = _entrySuffix.getAttribute("cn");
-        if ( suffixCN != null ){
-            _suffix = MappingUtils.unQuote( suffixCN.getStringValueArray()[0]);
-        } 
+        _suffix = MappingUtils.getMappingNodeSuffix(_entrySuffix);
         _suffixLabel =  makeJLabel( _section, "suffix-name" );
         gbc.gridwidth = 3;
         gbc.fill = gbc.NONE;
@@ -309,7 +306,7 @@ public class NewLDBMPanel extends BlankPanel {
         }
     }
 
-    public int addLDBMBackend(String _MappingNode ) {
+    public int addLDBMBackend(String suffix ) {
 
         String _instName = _instanceNameText.getText().trim();
 
@@ -335,7 +332,7 @@ public class NewLDBMPanel extends BlankPanel {
         attrs.add( new LDAPAttribute( "cn", cn_dbInst ) );
 
                                    
-        String suffix_dbInstConfig[] = { _MappingNode };
+        String suffix_dbInstConfig[] = { suffix };
         attrs.add( new LDAPAttribute ( "nsslapd-suffix", suffix_dbInstConfig ));
 
         String cachesize_dbInstConfig[] = { "-1" };
