@@ -81,10 +81,23 @@ public class SchemaAttributesPanel extends BlankPanel
 		return "";
 	}
 
-		/**
-		  * Takes an ID in format 1.2.3.4{128} and creates an ID  without the length definition.
-		  * In this case the resulting ID is 1.2.3.4 
-		  */
+	// Create a hashtable of matching rule names to the AVA syntax OIDs
+	static Hashtable getMatchingRuleStrings(LDAPSchema sch) {
+		Hashtable htMatchingRuleStrings = new Hashtable();
+		Enumeration matchingrules = sch.getMatchingRules();
+		while (matchingrules.hasMoreElements()) {
+			LDAPMatchingRuleSchema mr = (LDAPMatchingRuleSchema)matchingrules.nextElement();
+			if (mr != null) {
+				htMatchingRuleStrings.put(mr.getName(), mr.getSyntaxString());
+			}
+		}
+		return htMatchingRuleStrings;
+	}
+
+	/**
+	  * Takes an ID in format 1.2.3.4{128} and creates an ID  without the length definition.
+	  * In this case the resulting ID is 1.2.3.4 
+	  */
 	private static String getNormalizedID(String id) {
 		String normalizedId;
 		int index = id.indexOf('{');
@@ -236,9 +249,12 @@ public class SchemaAttributesPanel extends BlankPanel
 		String dummy = new String(); // for getClass()
         Object[][] colHeader = {
 			{DSUtil._resource.getString(_section, "namecolumn-label"), dummy.getClass()},
-		    {DSUtil._resource.getString(_section, "oidcolumn-label"), dummy.getClass()},
-		    {DSUtil._resource.getString(_section, "syntaxcolumn-label"), dummy.getClass()},
-		    {DSUtil._resource.getString(_section, "multicolumn-label"), Boolean.TYPE}
+			{DSUtil._resource.getString(_section, "oidcolumn-label"), dummy.getClass()},
+			{DSUtil._resource.getString(_section, "syntaxcolumn-label"), dummy.getClass()},
+			{DSUtil._resource.getString(_section, "multicolumn-label"), Boolean.TYPE},
+			{DSUtil._resource.getString(_section, "mrequality-label"), dummy.getClass()},
+			{DSUtil._resource.getString(_section, "mrordering-label"), dummy.getClass()},
+			{DSUtil._resource.getString(_section, "mrsubstring-label"), dummy.getClass()}
 		};
 
         /* create standard attributes panel */
@@ -768,8 +784,12 @@ class AttrTableModel extends AbstractTableModel {
 		}
 	}
 	void addRow(LDAPAttributeSchema las) {
-		Object row[] = new Object[4];
+		Object row[] = new Object[7];
 		String name = las.getName();
+		String [] mr_eq_vals = las.getQualifier("EQUALITY");
+		String [] mr_ord_vals = las.getQualifier("ORDERING");
+		String [] mr_sub_vals = las.getQualifier("SUBSTR");
+
 //		can't have alias list as first column in table because the code uses
 //		that value to look up the attribute schema
 //		String[] aliases = las.getAliases();
@@ -781,6 +801,18 @@ class AttrTableModel extends AbstractTableModel {
 		row[1] = las.getID();
 		row[2] = SchemaAttributesPanel.getSyntaxString(las.getSyntaxString());
 		row[3] = new Boolean( !las.isSingleValued() );
+
+		// Fill in any matching rules that are set
+		if ((mr_eq_vals != null) && (mr_eq_vals.length > 0)) {
+			row[4] = mr_eq_vals[0];
+		}
+		if ((mr_ord_vals != null) && (mr_ord_vals.length > 0)) {
+			row[5] = mr_ord_vals[0];
+		}
+		if ((mr_sub_vals != null) && (mr_sub_vals.length > 0)) {
+			row[6] = mr_sub_vals[0];
+		}
+
 		addRow(row);
 	}
 	void addRow( Object[] values ) {
